@@ -1,7 +1,10 @@
 package Net::Delicious::Constants::Uri;
 use strict;
 
-# $Id: Uri.pm,v 1.6 2005/12/30 17:51:40 asc Exp $
+# $Id: Uri.pm,v 1.7 2006/01/13 17:09:11 asc Exp $
+$Net::Delicious::Constants::Uri::VERSION = '0.96';
+
+use URI;
 
 =head1 NAME
 
@@ -14,10 +17,7 @@ Net::Delicious::Constants::Uri - constant variables for del.icio.us URIs
 =head1 DESCRIPTION
 
 Constant variables for del.icio.us URIs.
-
-=cut
-
-$Net::Delicious::Constants::Uri::VERSION = '0.95';
+cut
 
 =head1 CONSTANTS
 
@@ -29,7 +29,7 @@ String.
 
 =cut
 
-use constant URI_DELICIOUS => "http://del.icio.us";
+use constant URI_DELICIOUS => URI->new("http://del.icio.us");
 
 =head2 URI_API
 
@@ -37,7 +37,7 @@ String.
 
 =cut
 
-use constant URI_API => join("/",URI_DELICIOUS,"api");
+use constant URI_API => URI->new_abs("api/", URI_DELICIOUS); 
 
 BEGIN {
   use vars qw (@EXPORT_OK);
@@ -48,11 +48,11 @@ BEGIN {
 
 =head1 VERSION
 
-0.95
+0.96
 
 =head1 DATE
 
-$Date: 2005/12/30 17:51:40 $
+$Date: 2006/01/13 17:09:11 $
 
 =head1 AUTHOR
 
@@ -66,7 +66,7 @@ L<Net::Delicious::Constants>
 
 =head1 LICENSE
 
-Copyright (c) 2004-2005 Aaron Straup Cope. All rights reserved.
+Copyright (c) 2004-2006 Aaron Straup Cope. All rights reserved.
 
 This is free software, you may use it and distribute it under the
 same terms as Perl itself.
