@@ -1,10 +1,10 @@
-# $Id: Subscription.pm,v 1.8 2005/12/30 17:51:40 asc Exp $
+# $Id: Subscription.pm,v 1.9 2006/01/13 17:09:11 asc Exp $
 use strict;
 
 package Net::Delicious::Subscription;
 use base qw (Net::Delicious::Object);
 
-$Net::Delicious::Subscription::VERSION = '0.95';
+$Net::Delicious::Subscription::VERSION = '0.96';
 
 =head1 NAME
 
@@ -94,7 +94,7 @@ Returns a string.
 
 sub url {
     my $self = shift;
-    return join("/",URI_DELICIOUS,$self->user(),$self->tag());
+    return URI->new_abs(join("/", $self->user(),$self->tag()), URI_DELICIOUS); 
 }
 
 =head2 $obj->as_hashref()
@@ -112,11 +112,11 @@ sub _properties {
 
 =head1 VERSION
 
-0.95
+0.96
 
 =head1 DATE
 
-$Date: 2005/12/30 17:51:40 $
+$Date: 2006/01/13 17:09:11 $
 
 =head1 AUTHOR
 
@@ -128,7 +128,7 @@ L<Net::Delicious>
 
 =head1 LICENSE
 
-Copyright (c) 2004-2005 Aaron Straup Cope. All rights reserved.
+Copyright (c) 2004-2006 Aaron Straup Cope. All rights reserved.
 
 This is free software, you may use it and distribute it under the
 same terms as Perl itself.
